@@ -24,7 +24,12 @@ require_once ("../include/php_setup.inc");
 require_once ("functions.inc");
 require_once ("variables.inc");
 require_once ("class_logging.inc");
-header("Content-type: text/html; charset=UTF-8");
+
+/* Set headers */
+header('Content-type: text/html; charset=UTF-8');
+header('X-XSS-Protection: 1; mode=block');
+header('X-Content-Type-Options: nosniff');
+header('X-Frame-Options: deny');
 
 /* Display the login page and exit() */
 function displayLogin()
@@ -113,9 +118,9 @@ if (isset($_REQUEST['signout']) && $_REQUEST['signout']) {
     $config = session::global_get('config');
     if ($config->get_cfg_value('casActivated') == 'TRUE') {
       require_once('CAS.php');
-      /* Move CAS autoload before FD autoload */
-      spl_autoload_unregister('CAS_autoload');
-      spl_autoload_register('CAS_autoload', TRUE, TRUE);
+      /* Move FD autoload after CAS autoload */
+      spl_autoload_unregister('__fusiondirectory_autoload');
+      spl_autoload_register('__fusiondirectory_autoload');
       phpCAS::client(
         CAS_VERSION_2_0,
         $config->get_cfg_value('casHost', 'localhost'),
@@ -192,7 +197,10 @@ if (isset($_POST['server'])) {
 }
 
 $config->set_current($server);
-if (($config->get_cfg_value('casActivated') == 'TRUE') || ($config->get_cfg_value('httpAuthActivated') == 'TRUE')) {
+if (
+  ($config->get_cfg_value('casActivated') == 'TRUE') ||
+  ($config->get_cfg_value('httpAuthActivated') == 'TRUE') ||
+  ($config->get_cfg_value('httpHeaderAuthActivated') == 'TRUE')) {
   session::global_set('DEBUGLEVEL', 0);
 }
 
@@ -207,9 +215,6 @@ if (isset($_REQUEST['message'])) {
     case 'expired':
       $message = _('Your FusionDirectory session has expired!');
       break;
-    case 'newip':
-      $message = _('Your IP has changed!');
-      break;
     case 'invalidparameter':
       $message = sprintf(_('Invalid plugin parameter "%s"!'), $_REQUEST['plug']);
       break;
@@ -325,6 +330,9 @@ class Index {
     session::global_un_set('plist');
     $plist = load_plist();
 
+    /* Check that newly installed plugins have their configuration in the LDAP (will reload plist if needed) */
+    $config->checkLdapConfig();
+
     /* Check account expiration */
     if ($config->get_cfg_value('handleExpiredAccounts') == 'TRUE') {
       $expired = $ui->expired_status();
@@ -346,8 +354,6 @@ class Index {
     /* Not account expired or password forced change go to main page */
     logging::log('security', 'login', '', array(), 'User "'.static::$username.'" logged in successfully.');
     session::global_set('connected', 1);
-    // check that newly installed plugins have their configuration in the LDAP
-    $config->checkLdapConfig();
     session::global_set('DEBUGLEVEL', $config->get_cfg_value('DEBUGLEVEL'));
     header ('Location: main.php?global_check=1');
     exit;
@@ -393,9 +399,9 @@ class Index {
     $success = static::runSteps(array(
       'validateUserInput',
       'ldapLoginUser',
+      'checkForLockingBranch',
       'loginAndCheckExpired',
       'runSchemaCheck',
-      'checkForLockingBranch',
     ));
 
     if ($success) {
@@ -421,9 +427,9 @@ class Index {
     $success = static::runSteps(array(
       'validateUserInput',
       'ldapLoginUser',
+      'checkForLockingBranch',
       'loginAndCheckExpired',
       'runSchemaCheck',
-      'checkForLockingBranch',
     ));
 
     if ($success) {
@@ -460,16 +466,9 @@ class Index {
       exit();
     }
 
-    $ldap = $config->get_ldap_link();
-    $ldap->cd($config->current['BASE']);
-    $verify_attr = explode(',', $config->get_cfg_value('loginAttribute', 'uid'));
-    $filter = '';
-    foreach ($verify_attr as $attr) {
-      $filter .= '('.$attr.'='.ldap_escape_f(static::$username).')';
-    }
-    $ldap->search('(&(|'.$filter.')(objectClass=inetOrgPerson))');
-    $attrs = $ldap->fetch();
-    if ($ldap->count() < 1) {
+    $ui = ldap_get_user(static::$username);
+
+    if ($ui === FALSE) {
       msg_dialog::display(
         _('Error'),
         sprintf(
@@ -479,24 +478,25 @@ class Index {
         FATAL_ERROR_DIALOG
       );
       exit();
-    } elseif ($ldap->count() > 1) {
+    } elseif (is_string($ui)) {
       msg_dialog::display(
         _('Error'),
         sprintf(
-          _('Header user "%s" match several users in the LDAP'),
-          static::$username
+          _('Login with user "%s" triggered error: %s'),
+          static::$username,
+          $ui
         ),
         FATAL_ERROR_DIALOG
       );
       exit();
     }
-    $ui = new userinfo($config, $attrs['dn']);
+
     $ui->loadACL();
 
     $success = static::runSteps(array(
+      'checkForLockingBranch',
       'loginAndCheckExpired',
       'runSchemaCheck',
-      'checkForLockingBranch',
     ));
 
     if ($success) {
@@ -532,16 +532,10 @@ class Index {
     // force CAS authentication
     phpCAS::forceAuthentication();
     static::$username = phpCAS::getUser();
-    $ldap = $config->get_ldap_link();
-    $ldap->cd($config->current['BASE']);
-    $verify_attr = explode(',', $config->get_cfg_value('loginAttribute', 'uid'));
-    $filter = '';
-    foreach ($verify_attr as $attr) {
-      $filter .= '('.$attr.'='.ldap_escape_f(static::$username).')';
-    }
-    $ldap->search('(&(|'.$filter.')(objectClass=inetOrgPerson))');
-    $attrs = $ldap->fetch();
-    if ($ldap->count() < 1) {
+
+    $ui = ldap_get_user(static::$username);
+
+    if ($ui === FALSE) {
       msg_dialog::display(
         _('Error'),
         sprintf(
@@ -551,24 +545,25 @@ class Index {
         FATAL_ERROR_DIALOG
       );
       exit();
-    } elseif ($ldap->count() > 1) {
+    } elseif (is_string($ui)) {
       msg_dialog::display(
         _('Error'),
         sprintf(
-          _('CAS user "%s" match several users in the LDAP'),
-          static::$username
+          _('Login with user "%s" triggered error: %s'),
+          static::$username,
+          $ui
         ),
         FATAL_ERROR_DIALOG
       );
       exit();
     }
-    $ui = new userinfo($config, $attrs['dn']);
+
     $ui->loadACL();
 
     $success = static::runSteps(array(
+      'checkForLockingBranch',
       'loginAndCheckExpired',
       'runSchemaCheck',
-      'checkForLockingBranch',
     ));
 
     if ($success) {
@@ -582,9 +577,9 @@ if ($config->get_cfg_value('httpAuthActivated') == 'TRUE') {
   Index::authLoginProcess();
 } elseif ($config->get_cfg_value('casActivated') == 'TRUE') {
   require_once('CAS.php');
-  /* Move CAS autoload before FD autoload */
-  spl_autoload_unregister('CAS_autoload');
-  spl_autoload_register('CAS_autoload', TRUE, TRUE);
+  /* Move FD autoload after CAS autoload */
+  spl_autoload_unregister('__fusiondirectory_autoload');
+  spl_autoload_register('__fusiondirectory_autoload');
   Index::casLoginProcess();
 } elseif ($config->get_cfg_value('httpHeaderAuthActivated') == 'TRUE') {
   Index::headerAuthLoginProcess();
